[libpng15] Imported from libpng-1.5.17beta01.tar
diff --git a/LICENSE b/LICENSE
index 252fc42..883516d 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.17beta01, May 23, 2013, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.17beta01, June 8, 2013, are
 Copyright (c) 2004, 2006-2012 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-May 23, 2013
+June 8, 2013
diff --git a/README b/README
index 37f5edc..f9b85b3 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.17beta01 - June 5, 2013 (shared library 15.0)
+README for libpng version 1.5.17beta01 - June 8, 2013 (shared library 15.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
diff --git a/arm/arm_init.c b/arm/arm_init.c
index e929ea2..a55d6a6 100644
--- a/arm/arm_init.c
+++ b/arm/arm_init.c
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2013 Glenn Randers-Pehrson
  * Written by Mans Rullgard, 2011.
- * Last changed in libpng 1.5.16 [May 23, 2013]
+ * Last changed in libpng 1.5.17 [$RDATE%]
  *
  * This code is released under the libpng license.
  * For conditions of distribution and use, see the disclaimer
diff --git a/arm/filter_neon.S b/arm/filter_neon.S
index 1361eca..e21f2eb 100644
--- a/arm/filter_neon.S
+++ b/arm/filter_neon.S
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2013 Glenn Randers-Pehrson
  * Written by Mans Rullgard, 2011.
- * Last changed in libpng 1.5.16 [May 23, 2013]
+ * Last changed in libpng 1.5.17 [$RDATE%]
  *
  * This code is released under the libpng license.
  * For conditions of distribution and use, see the disclaimer
diff --git a/config.h.in b/config.h.in
index cad335d..8693551 100644
--- a/config.h.in
+++ b/config.h.in
@@ -80,10 +80,7 @@
 #undef PNG_ARM_NEON_CHECK_SUPPORTED
 
 /* Enable ARM Neon optimizations */
-#undef PNG_ARM_NEON_SUPPORTED
-
-/* Disable ARM Neon optimizations */
-#undef PNG_NO_ARM_NEON
+#undef PNG_ARM_NEON_OPT
 
 /* Define to 1 if you have the ANSI C header files. */
 #undef STDC_HEADERS
diff --git a/configure b/configure
index 4799882..aba34e8 100755
--- a/configure
+++ b/configure
@@ -1439,7 +1439,8 @@
                           use internal checking code (deprecated and poorly
                           supported); api: disable by default, enable by a
                           call to png_set_option; yes/on: turn on
-                          unconditionally.
+                          unconditionally. If not specified: determined by the
+                          compiler.
 
 Optional Packages:
   --with-PACKAGE[=ARG]    use PACKAGE [ARG=yes]
@@ -12821,7 +12822,7 @@
       no|off)
          # disable the default enabling on __ARM_NEON__ systems:
 
-$as_echo "#define PNG_NO_ARM_NEON /**/" >>confdefs.h
+$as_echo "#define PNG_ARM_NEON_OPT 0" >>confdefs.h
 
          # Prevent inclusion of the assembler files below:
          enable_arm_neon=no;;
@@ -12835,8 +12836,14 @@
 ;;
       yes|on)
 
-$as_echo "#define PNG_ARM_NEON_SUPPORTED /**/" >>confdefs.h
-;;
+$as_echo "#define PNG_ARM_NEON_OPT 2" >>confdefs.h
+
+         { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: --enable-arm-neon: please specify 'check' or 'api', if
+            you want the optimizations unconditionally pass -mfpu=neon
+            to the compiler." >&5
+$as_echo "$as_me: WARNING: --enable-arm-neon: please specify 'check' or 'api', if
+            you want the optimizations unconditionally pass -mfpu=neon
+            to the compiler." >&2;};;
       *)
          as_fn_error $? "--enable-arm-neon=${enable_arm_neon}: invalid value" "$LINENO" 5
    esac
diff --git a/libpng-manual.txt b/libpng-manual.txt
index c5e6a21..a86c5b3 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
 Libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.17beta01 - May 23, 2013
+ libpng version 1.5.17beta01 - June 8, 2013
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2013 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.17beta01 - May 23, 2013
+ libpng versions 0.97, January 1998, through 1.5.17beta01 - June 8, 2013
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2013 Glenn Randers-Pehrson
 
@@ -4655,7 +4655,7 @@
 
 XIV. Y2K Compliance in libpng
 
-May 23, 2013
+June 8, 2013
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
diff --git a/libpng.3 b/libpng.3
index 7f9b1a0..abf129a 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "May 23, 2013"
+.TH LIBPNG 3 "June 8, 2013"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.5.17beta01
 .SH SYNOPSIS
@@ -492,7 +492,7 @@
 .SH LIBPNG.TXT
 Libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.17beta01 - May 23, 2013
+ libpng version 1.5.17beta01 - June 8, 2013
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2013 Glenn Randers-Pehrson
@@ -503,7 +503,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.17beta01 - May 23, 2013
+ libpng versions 0.97, January 1998, through 1.5.17beta01 - June 8, 2013
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2013 Glenn Randers-Pehrson
 
@@ -5148,7 +5148,7 @@
 
 .SH XIV. Y2K Compliance in libpng
 
-May 23, 2013
+June 8, 2013
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
@@ -5440,7 +5440,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.5.17beta01 - May 23, 2013:
+Libpng version 1.5.17beta01 - June 8, 2013:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -5463,7 +5463,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.17beta01, May 23, 2013, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.17beta01, June 8, 2013, are
 Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -5562,7 +5562,7 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-May 23, 2013
+June 8, 2013
 
 .\" end of man page
 
diff --git a/libpngpf.3 b/libpngpf.3
index 2954b6c..7981823 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "May 23, 2013"
+.TH LIBPNGPF 3 "June 8, 2013"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.5.17beta01
 (private functions)
diff --git a/png.5 b/png.5
index 678038d..7f91e4c 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "May 23, 2013"
+.TH PNG 5 "June 8, 2013"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
diff --git a/png.c b/png.c
index 944b111..891eb29 100644
--- a/png.c
+++ b/png.c
@@ -658,13 +658,13 @@
 #else
 #  ifdef __STDC__
    return PNG_STRING_NEWLINE \
-     "libpng version 1.5.17beta01 - May 23, 2013" PNG_STRING_NEWLINE \
+     "libpng version 1.5.17beta01 - June 8, 2013" PNG_STRING_NEWLINE \
      "Copyright (c) 1998-2013 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
      "Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
      "Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
      PNG_STRING_NEWLINE;
 #  else
-      return "libpng version 1.5.17beta01 - May 23, 2013\
+      return "libpng version 1.5.17beta01 - June 8, 2013\
       Copyright (c) 1998-2013 Glenn Randers-Pehrson\
       Copyright (c) 1996-1997 Andreas Dilger\
       Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngpriv.h b/pngpriv.h
index cd098c0..d815c0b 100644
--- a/pngpriv.h
+++ b/pngpriv.h
@@ -6,7 +6,7 @@
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
  *
- * Last changed in libpng 1.5.15 [March 28, 2013]
+ * Last changed in libpng 1.5.17 [(PENDING RELEASE)]
  *
  * This code is released under the libpng license.
  * For conditions of distribution and use, see the disclaimer
diff --git a/pngset.c b/pngset.c
index 76d4754..342d9cc 100644
--- a/pngset.c
+++ b/pngset.c
@@ -1,7 +1,7 @@
 
 /* pngset.c - storage of image information into info struct
  *
- * Last changed in libpng 1.5.14 [January 24, 2013]
+ * Last changed in libpng 1.5.17 [(PENDING RELEASE)]
  * Copyright (c) 1998-2013 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index 5e58830..9576d81 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
 
 VisualStudio instructions
 
-libpng version 1.5.17beta01 - May 23, 2013
+libpng version 1.5.17beta01 - June 8, 2013
 
 Copyright (c) 1998-2010 Glenn Randers-Pehrson
 
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 059f4ea..bedec9a 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
 <!--
  * zlib.props - location of zlib source
  *
- * libpng version 1.5.17beta01 - May 23, 2013
+ * libpng version 1.5.17beta01 - June 8, 2013
  *
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  *
diff --git a/scripts/README.txt b/scripts/README.txt
index 6edb49a..7b88d66 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
 
-Makefiles for  libpng version 1.5.17beta01 - May 23, 2013
+Makefiles for  libpng version 1.5.17beta01 - June 8, 2013
 
 pnglibconf.h.prebuilt       =>  Stores configuration settings
  makefile.linux    =>  Linux/ELF makefile
diff --git a/png.h b/png.h
index a465064..769f091 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.5.17beta01 - May 23, 2013
  * Copyright (c) 1998-2013 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *   libpng versions 0.97, January 1998, through 1.5.17beta01 - May 23, 2013: Glenn
  *   See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -222,7 +222,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.5.17beta01, May 23, 2013, are
  * Copyright (c) 2004, 2006-2013 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -334,7 +334,7 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    May 23, 2013
+ *    June 8, 2013
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
@@ -401,7 +401,7 @@
 /* Version information for png.h - this should match the version in png.c */
 #define PNG_LIBPNG_VER_STRING "1.5.17beta01"
 #define PNG_HEADER_VERSION_STRING \
-     " libpng version 1.5.17beta01 - May 23, 2013\n"
+     " libpng version 1.5.17beta01 - June 8, 2013\n"
 
 #define PNG_LIBPNG_VER_SONUM   15
 #define PNG_LIBPNG_VER_DLLNUM  15
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.5.17beta01 - May 23, 2013
+ * libpng version 1.5.17beta01 - June 8, 2013
  * Copyright (c) 1998-2013 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *   libpng versions 0.97, January 1998, through 1.5.17beta01 - May 23, 2013: Glenn
+ *   libpng versions 0.97, January 1998, through 1.5.17beta01 - June 8, 2013: Glenn
  *   See also "Contributing Authors", below.
  *
@@ -222,7 +222,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.5.17beta01, May 23, 2013, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.17beta01, June 8, 2013, are
  * Copyright (c) 2004, 2006-2013 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5